@@ -7,7 +7,7 @@ from voyant_indicators.overlapping_studies.dema import dema
 from voyant_indicators.overlapping_studies.tema import tema
 
 
-def accelerator_oscillator(df,high, low, col, ma_type, n =5, col='ac'):
+def accelerator_oscillator(df,high="high", low="low", col="ao", ma_type, n =5):
    
     ma_types = {"sma":sma, "ema" : ema, "wma": wma, "dema": dema, "tema": tema}
 
