@@ -2,7 +2,7 @@ import pandas as pd
 from voyant_indicators.trend.aroon import aroon
 
 
-def aroonosc(df, high, low, aroonosc, n):
+def aroonosc(df, high="high", low="low", col="aroonosc", n):
     """
     An Aroon Oscillator is a trend-following indicator that uses aspects of the
     Aroon Indicator ("Aroon Up" and "Aroon Down") to gauge the strength of a
@@ -13,7 +13,7 @@ def aroonosc(df, high, low, aroonosc, n):
         df (pd.DataFrame): DataFrame which contain the asset information.
         high (string): the column name for the period highest price  of the asset.
         low (string): the column name for the period lowest price of the asset.
-        aroonosc (string): the column name for the results of aroonosc.
+        col (string): the column name for the results of aroonosc.
         n (int): the total number of periods.
 
     Returns:
@@ -22,7 +22,7 @@ def aroonosc(df, high, low, aroonosc, n):
     """
 
     df = aroon(df, high, low, "aroon", n)
-    df[aroonosc] = df["aroon_up"] - df["aroon_dn"]
+    df[col] = df["aroon_up"] - df["aroon_dn"]
     df.drop(["aroon_up", "aroon_dn"], axis=1, inplace=True)
 
     return df
