@@ -2,7 +2,7 @@ import pandas as pd
 from voyant_indicators.trend.ema import ema
 
 
-def dema(df, price, col, n):
+def dema(df, price="close", col="dema", n):
     """
     Double Exponential Moving Average (DEMA) attempts to offer a smoothed average
     with less lag than a straight exponential moving average.
