@@ -7,10 +7,10 @@ from voyant_indicators.overlapping_studies.wma import wma
 from voyant_indicators.overlapping_studies.dema import dema
 from voyant_indicators.overlapping_studies.tema import tema
 
-from indicators.momentum.roc import roc
+from voyant_indicators.momentum.roc import roc
 
 
-def trix(df, price, trix, n):
+def trix(df, price="close", col="trix", n):
     """
     TRIX is a momentum oscillator that displays the percent rate of change of a
     triple exponentially smoothed moving average.
@@ -26,9 +26,9 @@ def trix(df, price, trix, n):
 
     """
 
-    df = ema(df, price, trix + "_ema", n)
-    df = ema(df[n - 1 :], trix + "_ema", trix + "_ema_2", n)
-    df = ema(df[n - 1 :], trix + "_ema_2", trix + "_ema_3", n)
-    df = roc(df, trix + "_ema_3", trix, 1)
+    df = ema(df, price, col + "_ema", n)
+    df = ema(df[n - 1 :], col + "_ema", col + "_ema_2", n)
+    df = ema(df[n - 1 :], col + "_ema_2", col + "_ema_3", n)
+    df = roc(df, col + "_ema_3", col, 1)
 
     return df
